import { createSignal, For } from "solid-js";
// Importieren der fetchUser Funktion
import { fetchUsers } from "../stores/PersonStore";

function PersonTable() {
  // Ressourcen sind für asynchrone Ereignisse konzipiert. 
  // Solid kann so eine Anfrage an den Server stellen und wenn dieser geantwortet hat, 
  // automatisch die Komponente rendern ohne die Komponente anzuhalten und zu blockieren. 
  // "Hole mir die Daten, wenn du sie hast, melde dich und render neu."
  // fetchUsers wird einmal aufgerufen, wenn die Komponente rendert. 
  // Um die App besser zu struturieren, lagern wir fetchUser in die 
  // separate js-Datei ./stores/PersonStore.js aus und importieren die Funktion oben. 
  const [persons] = createResource(fetchUsers);

  return (
    <div class="overflow-x-auto mt-10 p-4">
      <h2 class="text-2xl font-bold mb-4">Personenliste</h2>
      <table class="table table-zebra w-full bg-base-100 rounded-xl shadow">
        <thead class="bg-base-200">
          <tr>
            <th>Username</th>
            <th>Vorname</th>
            <th>Nachname</th>
            <th>Alter</th>
            <th>Stadt</th>
          </tr>
        </thead>
        <tbody>
          {/* For each erlaubt das iterieren des Arrays persons() - es bleibt reaktiv, 
              Wenn ein Array-Element oder ein Attribut in persons() verändert wird, wird neu gerendert
              Vom Prinzip gleich wie map-Funktion.
           */}
          <For each={persons()}>
            {(person) => (
              <tr>
                <td>{person.username}</td>
                <td>{person.prename}</td>
                <td>{person.surname}</td>
                <td>{person.age}</td>
                <td>{person.city}</td>
              </tr>
            )}
          </For>
        </tbody>
      </table>
    </div>
  );
}

export default PersonTable;
