import { createSignal } from "solid-js";

// Wichtig: Diese Komponenten läuft im Frontend: Heißt, beim Aufruf der 
// Seite Solid wird diese JS Datei umgewandelt und an den Browser geschickt. 
// Alles was hier passiert, passiert im Browser und damit auf dem 
// Gerät des Nutzers. Alles, was hier an UI Logik gemacht wird, braucht auf dem 
// Server keine Rechenpower mehr. Dazu muss die Komponente mit client:load aufgerufen 
// werden --> hier in solid.astro. Zur Visualisierung des dynamischen Bereichs wurde
// ein Border eingefügt. 
export default function SolidUiElement(props) { 
    // States speicherm Zustände in Form von Variablen. 
    // diese Variablen können durch Aufruf der ersten Funktion ausgelesen werden 
    // Beispiel noClicks() liefert den gespeicherten Integer des Zustandes. 
    // setNoClicks(...) wird zum Setzen benötigt. 
    // Wann immer ein State gesetzt wird, wird die Komponenten neu gerendert. 
    // Mit anderen Worten: Wird der State geändert, wird jeder Teil der Seite 
    // upgedated, der die geänderte Variable enthält. 
    const [noClicks, setNoClicks] = createSignal(0);

    // Um den Text im Editfeld zu speichern, wird wieder ein State definiert. 
    // Der Parameter in createSignal ist der default Wert, der beim erstmaligen 
    // Aufruf der Komponente gesetzt wird. 
    const [prename, setPrename] = createSignal("Lea");
    const [surname, setSurname] = createSignal("");

    let prenameChanged = (e) => {
        console.log("e aus prenameChanged", e);
        let editFieldText = e.target.value;
        console.log("editFieldText: ", editFieldText)
        setPrename(editFieldText)
    }

    let surnameChanged = (e) => {
        let editFieldText = e.target.value; 
        setSurname(editFieldText)
    } 

    return (
        <div className="border border-indigo-800 p-10 " data-theme={props.theme}>
            <h1 class="text-4xl">Solid</h1>
            <p class="text-lg">Diese Komponente läuft im Browser.</p>
            <div class="join">
                <button class="btn join-item btn-secondary" onClick={ () => { setNoClicks( noClicks() - 1)}}>
                    Down 
                </button>
                <button class="btn join-item btn-primary" onClick={ () => { setNoClicks( noClicks() + 1)}}>
                    Up 
                </button>
                <button class="btn join-item" onClick={ () => { setNoClicks( 0 )}}>
                    Reset 
                </button>
            </div>
            <p className={ noClicks() < 0 ? "text-xl text-red-800" : "text-xl text-green-800"}>
                Number of Clicks: <b>{ noClicks() }</b>
            </p>
            <div class="divider"></div> 
            <label class="input input-bordered flex items-center gap-2">
                <input type="text" class="grow" placeholder="Vorname..." value={ prename() } onInput = { prenameChanged }/>
            </label>
            <label class="input input-bordered flex items-center gap-2 my-2">
                <input type="text" class="grow" placeholder="Nachname..." value={ surname() } onInput = { surnameChanged } />
            </label>
            <p className={surname() === "Maier" ? "py-10 text-2xl text-red-800" : "py-5"} > 
                Entered Name: { prename().toUpperCase() + " " + surname().toUpperCase()}
            </p>
            <p className="py-5">
                Ist es Lena? { prename() === 'Lena' ? "ja" : "nein"}
            </p> 
        </div>
    )  
}
