import axios from "axios";

// Damit wir die URL global in einer Zeile ändern können, lagern wir diese in config.js aus. 
import config from "../../utils/config"
// Dieser Store bearbeitet (im Developmodul hier) die Route http:/localhost:3000/api/persondb
const baseUrl = config.baseUrl + "/api/persondb"

export const fetchPersons = async () => {
    try {
      const res = await axios.get(baseUrl, {
        timeout: 3000,
        headers: {
          Accept: "application/json",
        },
      });
      // console.log("res ",res)
      return res.data.persons;
    } catch (err) {
      console.log("catch");
  
      if (err.code === "ECONNABORTED") {
        throw new Error("Anfrage abgebrochen – Timeout überschritten (3 Sekunden)");
      }
  
      if (err.response) {
        throw new Error(`Serverfehler (${err.response.status}): ${err.response.statusText}`);
      }
  
      if (err.request) {
        throw new Error("Keine Antwort vom Server erhalten");
      }
  
      throw new Error(`Fehler beim Laden: ${err.message}`);
    }
  };
  
  export const postPerson = async (person) => {
    try {
      const res = await axios.post(baseUrl, person, {
        headers: {
          "Content-Type": "application/json",
        },
      });
      return res.data;
    } catch (err) {
      throw new Error(`Fehler beim Hinzufügen: ${err.message}`);
    }
  };
  
  export const putPerson = async (person) => {
    try {
      const res = await axios.put(baseUrl, person, {
        headers: {
          "Content-Type": "application/json",
        },
      });
      return res.data;
    } catch (err) {
      throw new Error(`Fehler beim Aktualisieren: ${err.message}`);
    }
  };
  
  export const deletePerson = async (id) => {
    try {
      const res = await axios.delete(baseUrl + `?id=${id}`);
      return res.data;
    } catch (err) {
      throw new Error(`Fehler beim Löschen: ${err.message}`);
    }
  };